Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(280)

Unified Diff: chrome/browser/ui/cocoa/browser_window_layout.h

Issue 2862003004: Mac: Fix infobar anchor under Harmony. (Closed)
Patch Set: s/. I/ i/ Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_layout.h
diff --git a/chrome/browser/ui/cocoa/browser_window_layout.h b/chrome/browser/ui/cocoa/browser_window_layout.h
index 6c96ccbf6b3c983b04310711a54fea5ac9585c6b..9444c171640dd1cf9b65ea0bfe3f6526d6466780 100644
--- a/chrome/browser/ui/cocoa/browser_window_layout.h
+++ b/chrome/browser/ui/cocoa/browser_window_layout.h
@@ -72,7 +72,7 @@ struct LayoutParameters {
// The distance from the bottom of the location icon to the bottom of the
// toolbar. Only needs to be set if infoBarHeight is not 0 and hasToolbar is
// YES.
- CGFloat pageInfoBubblePointY;
+ CGFloat infoBarAnchorPointY;
BOOL hasDownloadShelf;
CGFloat downloadShelfHeight;
@@ -172,8 +172,8 @@ struct LayoutOutput {
// The height of the info bar, not including the top arrow.
- (void)setInfoBarHeight:(CGFloat)infoBarHeight;
-// The min Y of the bubble point, relative to the toolbar.
-- (void)setPageInfoBubblePointY:(CGFloat)pageInfoBubblePointY;
+// The min Y of the infobar anchor point, relative to the toolbar.
+- (void)setInfoBarAnchorPointY:(CGFloat)infoBarAnchorPointY;
- (void)setHasDownloadShelf:(BOOL)hasDownloadShelf;
- (void)setDownloadShelfHeight:(CGFloat)downloadShelfHeight;
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_controller_private.mm ('k') | chrome/browser/ui/cocoa/browser_window_layout.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698